ControlFlowGraph

Struct ControlFlowGraph 

pub struct ControlFlowGraph {
    pub root: usize,
    pub predecessors: Vec<Vec<usize>>,
    pub successors: Vec<Vec<usize>>,
    pub dominators: DominatorTree,
    pub dominance_frontier: Vec<Vec<usize>>,
    pub postdominators: PostDominatorTree,
    pub postdominance_frontier: Vec<Vec<usize>>,
    pub controllers: Vec<Vec<usize>>,
    pub control_dependents: Vec<Vec<usize>>,
    pub sccs: Vec<StronglyConnectedRegion>,
    pub scc_for_block: Vec<usize>,
    pub loops: Vec<NaturalLoop>,
}
Complete analysis of one reachable dense CFG.

Fields

root: usizepredecessors: Vec<Vec<usize>>successors: Vec<Vec<usize>>dominators: DominatorTreedominance_frontier: Vec<Vec<usize>>postdominators: PostDominatorTreepostdominance_frontier: Vec<Vec<usize>>controllers: Vec<Vec<usize>>control_dependents: Vec<Vec<usize>>sccs: Vec<StronglyConnectedRegion>scc_for_block: Vec<usize>loops: Vec<NaturalLoop>

Implementations

Source

impl ControlFlowGraph

pub fn analyze( successors: Vec<Vec<usize>>, root: usize, ) -> Result<Self, CfgError>

Analyze a graph without changing the caller’s block numbering.

pub fn analyze_structure( successors: Vec<Vec<usize>>, root: usize, ) -> Result<Self, CfgError>

Analyze dominance, post-dominance, loops, and SCCs without constructing either dominance frontier or the potentially dense control-dependence relation.

Placement clients which only need legal region boundaries should use this mode. Its graph tables remain linear in the input CFG size.