pub struct ClobberQuery<'a, D, Q, A> { /* private fields */ }Expand description
Multi-point clobber query for one immutable alias query. Resolving a phi root and then its incoming states therefore visits each access at most once instead of restarting a whole-graph walk per edge.
Implementations
Sourceimpl<D, Q, A> ClobberQuery<'_, D, Q, A>where
A: AliasOracle<D, Q>,
impl<D, Q, A> ClobberQuery<'_, D, Q, A>where
A: AliasOracle<D, Q>,
pub fn clobber(&mut self, start: MemoryAccessId) -> Option<MemoryClobber>